This function suppresses logger when running tests via testthat.
To suppress logs for a single test, add this function
call within the testthat::test_that expression. To suppress logs for an entire
test file, call this function at the start of the file.