log_formatterCustom log_formatter supporting atomic vectors. By default glue::glue
returns n-element vector when vector is provided as an input. This function
generates "[elem1, elem2, ...]" for atomic vectors. Function also handles
NULL value which normally causes logger to return empty character.
teal_logger_formatter()teal_logger_transformer(text, envir)
Nothing. Called for its side effects.
Text (typically) R code to parse and evaluate.
environment to evaluate the code in